@@ -55,16 +55,16 @@ class Keybindings():
 
         # Setup local keys
         keys = [
-            'toggle-fullscreen', 'new-tab', 'close-tab', 'rename-current-tab', 'previous-tab',
-            'next-tab', 'clipboard-copy', 'clipboard-paste', 'quit', 'zoom-in', 'zoom-out',
-            'increase-height', 'decrease-height', 'increase-transparency', 'decrease-transparency',
-            'toggle-transparency', "search-on-web", 'move-tab-left', 'move-tab-right',
-            'switch-tab1', 'switch-tab2', 'switch-tab3', 'switch-tab4', 'switch-tab5',
-            'switch-tab6', 'switch-tab7', 'switch-tab8', 'switch-tab9', 'switch-tab10',
-            'switch-tab-last', 'reset-terminal', 'split-tab-vertical', 'split-tab-horizontal',
-            'close-terminal', 'focus-terminal-up', 'focus-terminal-down', 'focus-terminal-right',
-            'focus-terminal-left', 'move-terminal-split-up', 'move-terminal-split-down',
-            'move-terminal-split-left', 'move-terminal-split-right'
+            'toggle-fullscreen', 'new-tab', 'new-tab-home', 'close-tab', 'rename-current-tab',
+            'previous-tab', 'next-tab', 'clipboard-copy', 'clipboard-paste', 'quit', 'zoom-in',
+            'zoom-out', 'increase-height', 'decrease-height', 'increase-transparency',
+            'decrease-transparency', 'toggle-transparency', "search-on-web", 'move-tab-left',
+            'move-tab-right', 'switch-tab1', 'switch-tab2', 'switch-tab3', 'switch-tab4',
+            'switch-tab5', 'switch-tab6', 'switch-tab7', 'switch-tab8', 'switch-tab9',
+            'switch-tab10', 'switch-tab-last', 'reset-terminal', 'split-tab-vertical',
+            'split-tab-horizontal', 'close-terminal', 'focus-terminal-up', 'focus-terminal-down',
+            'focus-terminal-right', 'focus-terminal-left', 'move-terminal-split-up',
+            'move-terminal-split-down', 'move-terminal-split-left', 'move-terminal-split-right'
         ]
         for key in keys:
             guake.settings.keybindingsLocal.onChangedValue(key, self.reload_accelerators)
@@ -134,11 +134,18 @@ class Keybindings():
         if key > 0:
             self.accel_group.connect(key, mask, Gtk.AccelFlags.VISIBLE, self.guake.accel_add)
 
+        key, mask = Gtk.accelerator_parse(getk('new-tab-home'))
+        if key > 0:
+            self.accel_group.connect(key, mask, Gtk.AccelFlags.VISIBLE, self.guake.accel_add_home)
+
         key, mask = Gtk.accelerator_parse(getk('close-tab'))
         if key > 0:
-            self.accel_group.connect(
-                key, mask, Gtk.AccelFlags.VISIBLE, self.guake.notebook.delete_page_current
-            )
+
+            def x(*args):
+                prompt_cfg = self.guake.settings.general.get_int('prompt-on-close-tab')
+                self.guake.get_notebook().delete_page_current(prompt=prompt_cfg)
+
+            self.accel_group.connect(key, mask, Gtk.AccelFlags.VISIBLE, x)
 
         key, mask = Gtk.accelerator_parse(getk('previous-tab'))
         if key > 0:
@@ -262,7 +269,7 @@ class Keybindings():
                 Gtk.AccelFlags.VISIBLE,
                 (
                     lambda *args:  # keep make style from concat this lines
-                    self.guake.notebook.get_current_terminal().get_parent().split_v() or True
+                    self.guake.get_notebook().get_current_terminal().get_parent().split_v() or True
                 )
             )
         key, mask = Gtk.accelerator_parse(getk('split-tab-horizontal'))
@@ -273,50 +280,46 @@ class Keybindings():
                 Gtk.AccelFlags.VISIBLE,
                 (
                     lambda *args:  # keep make style from concat this lines
-                    self.guake.notebook.get_current_terminal().get_parent().split_h() or True
+                    self.guake.get_notebook().get_current_terminal().get_parent().split_h() or True
                 )
             )
         key, mask = Gtk.accelerator_parse(getk('close-terminal'))
         if key > 0:
             self.accel_group.connect(
                 key, mask, Gtk.AccelFlags.VISIBLE,
-                (lambda *args: self.guake.notebook.get_current_terminal().kill() or True)
+                (lambda *args: self.guake.get_notebook().get_current_terminal().kill() or True)
             )
         key, mask = Gtk.accelerator_parse(getk('focus-terminal-up'))
         if key > 0:
             self.accel_group.connect(
                 key, mask, Gtk.AccelFlags.VISIBLE, (
-                    lambda *args:
-                        FocusMover(self.guake.window).move_up(
-                            self.guake.notebook.get_current_terminal()
-                        ) or True)
+                    lambda *args: FocusMover(self.guake.window).
+                    move_up(self.guake.get_notebook().get_current_terminal()) or True
+                )
             )
         key, mask = Gtk.accelerator_parse(getk('focus-terminal-down'))
         if key > 0:
             self.accel_group.connect(
                 key, mask, Gtk.AccelFlags.VISIBLE, (
-                    lambda *args:
-                        FocusMover(self.guake.window).move_down(
-                            self.guake.notebook.get_current_terminal()
-                        ) or True)
+                    lambda *args: FocusMover(self.guake.window).
+                    move_down(self.guake.get_notebook().get_current_terminal()) or True
+                )
             )
         key, mask = Gtk.accelerator_parse(getk('focus-terminal-right'))
         if key > 0:
             self.accel_group.connect(
                 key, mask, Gtk.AccelFlags.VISIBLE, (
-                    lambda *args:
-                        FocusMover(self.guake.window).move_right(
-                            self.guake.notebook.get_current_terminal()
-                        ) or True)
+                    lambda *args: FocusMover(self.guake.window).
+                    move_right(self.guake.get_notebook().get_current_terminal()) or True
+                )
             )
         key, mask = Gtk.accelerator_parse(getk('focus-terminal-left'))
         if key > 0:
             self.accel_group.connect(
                 key, mask, Gtk.AccelFlags.VISIBLE, (
-                    lambda *args:
-                        FocusMover(self.guake.window).move_left(
-                            self.guake.notebook.get_current_terminal()
-                        ) or True)
+                    lambda *args: FocusMover(self.guake.window).
+                    move_left(self.guake.get_notebook().get_current_terminal()) or True
+                )
             )
         key, mask = Gtk.accelerator_parse(getk('move-terminal-split-up'))
         if key > 0:
@@ -326,7 +329,7 @@ class Keybindings():
                 Gtk.AccelFlags.VISIBLE,
                 (
                     lambda *args:  # keep make style from concat this lines
-                    SplitMover.move_up(self.guake.notebook.get_current_terminal()) or True
+                    SplitMover.move_up(self.guake.get_notebook().get_current_terminal()) or True
                 )
             )
         key, mask = Gtk.accelerator_parse(getk('move-terminal-split-down'))
@@ -337,7 +340,7 @@ class Keybindings():
                 Gtk.AccelFlags.VISIBLE,
                 (
                     lambda *args:  # keep make style from concat this lines
-                    SplitMover.move_down(self.guake.notebook.get_current_terminal()) or True
+                    SplitMover.move_down(self.guake.get_notebook().get_current_terminal()) or True
                 )
             )
         key, mask = Gtk.accelerator_parse(getk('move-terminal-split-left'))
@@ -348,7 +351,7 @@ class Keybindings():
                 Gtk.AccelFlags.VISIBLE,
                 (
                     lambda *args:  # keep make style from concat this lines
-                    SplitMover.move_left(self.guake.notebook.get_current_terminal()) or True
+                    SplitMover.move_left(self.guake.get_notebook().get_current_terminal()) or True
                 )
             )
         key, mask = Gtk.accelerator_parse(getk('move-terminal-split-right'))
@@ -359,6 +362,6 @@ class Keybindings():
                 Gtk.AccelFlags.VISIBLE,
                 (
                     lambda *args:  # keep make style from concat this lines
-                    SplitMover.move_right(self.guake.notebook.get_current_terminal()) or True
+                    SplitMover.move_right(self.guake.get_notebook().get_current_terminal()) or True
                 )
             )
