@@ -167,6 +167,22 @@ def main():
         help=_('Return the selected tab label.')
     )
 
+    parser.add_option(
+        '--split-vertical',
+        dest='split_vertical',
+        action='store_true',
+        default=False,
+        help=_('Split the selected tab vertically.')
+    )
+
+    parser.add_option(
+        '--split-horizontal',
+        dest='split_horizontal',
+        action='store_true',
+        default=False,
+        help=_('Split the selected tab horizontally.')
+    )
+
     parser.add_option(
         '-e',
         '--execute-command',
@@ -203,6 +219,14 @@ def main():
                'selected tab.')
     )
 
+    parser.add_option(
+        '--change-palette',
+        dest='palette_name',
+        action='store',
+        default='',
+        help=_('Change Guake palette scheme')
+    )
+
     parser.add_option(
         '--rename-tab',
         dest='rename_tab',
@@ -244,6 +268,28 @@ def main():
         help=_('Do not execute the start up script')
     )
 
+    # checking mandatory dependencies
+    import gi
+
+    try:
+        gi.require_version('Gtk', '3.0')
+        gi.require_version('Gdk', '3.0')
+    except ValueError:
+        print("[ERROR] Unable to start Guake, missing mandatory dependency: GtK 3.0")
+        sys.exit(1)
+
+    try:
+        gi.require_version('Vte', '2.91')  # vte-0.42
+    except ValueError:
+        print("[ERROR] Unable to start Guake, missing mandatory dependency: Vte >= 0.42")
+        sys.exit(1)
+
+    try:
+        gi.require_version('Keybinder', '3.0')
+    except ValueError:
+        print("[ERROR] Unable to start Guake, missing mandatory dependency: Keybinder 3")
+        sys.exit(1)
+
     options = parser.parse_args()[0]
     if options.version:
         from guake import gtk_version
@@ -310,9 +356,11 @@ def main():
 
     if options.select_tab:
         selected = int(options.select_tab)
-        i = remote_object.select_tab(selected)
-        if i is None:
-            sys.stdout.write('invalid index: %d\n' % selected)
+        tab_count = int(remote_object.get_tab_count())
+        if 0 <= selected < tab_count:
+            remote_object.select_tab(selected)
+        else:
+            sys.stderr.write('invalid index: %d\n' % selected)
         only_show_hide = False
 
     if options.selected_tab:
@@ -325,6 +373,14 @@ def main():
         sys.stdout.write('%s\n' % selectedlabel)
         only_show_hide = False
 
+    if options.split_vertical:
+        remote_object.v_split_current_terminal()
+        only_show_hide = False
+
+    if options.split_horizontal:
+        remote_object.h_split_current_terminal()
+        only_show_hide = False
+
     if options.command:
         remote_object.execute_command(options.command)
         only_show_hide = False
@@ -344,6 +400,10 @@ def main():
         remote_object.set_fgcolor(options.fgcolor)
         only_show_hide = False
 
+    if options.palette_name:
+        remote_object.change_palette_name(options.palette_name)
+        only_show_hide = False
+
     if options.rename_current_tab:
         remote_object.rename_current_tab(options.rename_current_tab)
         only_show_hide = False
