@@ -32,6 +32,7 @@ gi.require_version('Vte', '2.91')  # vte-0.38
 from gi.repository import GLib
 from gi.repository import GObject
 from gi.repository import Gdk
+from gi.repository import Gio
 from gi.repository import Gtk
 from gi.repository import Keybinder
 from gi.repository import Pango
@@ -48,6 +49,7 @@ from guake.globals import ALIGN_LEFT
 from guake.globals import ALIGN_RIGHT
 from guake.globals import ALIGN_TOP
 from guake.globals import ALWAYS_ON_PRIMARY
+from guake.globals import MAX_TRANSPARENCY
 from guake.globals import NAME
 from guake.globals import QUICK_OPEN_MATCHERS
 from guake.globals import bindtextdomain
@@ -123,6 +125,10 @@ HOTKEYS = [
                 'key': 'new-tab',
                 'label': _('New tab')
             },
+            {
+                'key': 'new-tab-home',
+                'label': _('New tab in home directory')
+            },
             {
                 'key': 'close-tab',
                 'label': _('Close tab')
@@ -382,6 +388,11 @@ class PrefsCallbacks():
         """
         self.settings.general.set_boolean('use-popup', chk.get_active())
 
+    def on_workspace_specific_tab_sets_toggled(self, chk):
+        """Sets the 'workspace-specific-tab-sets' property in dconf
+        """
+        self.settings.general.set_boolean('workspace-specific-tab-sets', chk.get_active())
+
     def on_prompt_on_quit_toggled(self, chk):
         """Set the `prompt on quit' property in dconf
         """
@@ -611,7 +622,7 @@ class PrefsCallbacks():
         """
         value = hscale.get_value()
         self.prefDlg.set_colors_from_settings()
-        self.settings.styleBackground.set_int('transparency', int(value))
+        self.settings.styleBackground.set_int('transparency', MAX_TRANSPARENCY - int(value))
 
     # compatibility tab
 
@@ -768,6 +779,11 @@ class PrefsDialog(SimpleGladeApp):
 
         self.demo_terminal.pid = pid
 
+        self.settings.general.bind(
+            'tab-close-buttons', self.get_widget('tab-close-buttons'), 'active',
+            Gio.SettingsBindFlags.DEFAULT
+        )
+
         self.populate_shell_combo()
         self.populate_keys_tree()
         self.populate_display_n()
@@ -1061,6 +1077,10 @@ class PrefsDialog(SimpleGladeApp):
         value = self.settings.general.get_boolean('use-popup')
         self.get_widget('use_popup').set_active(value)
 
+        # workspace-specific tab sets
+        value = self.settings.general.get_boolean('workspace-specific-tab-sets')
+        self.get_widget('workspace-specific-tab-sets').set_active(value)
+
         # prompt on quit
         value = self.settings.general.get_boolean('prompt-on-quit')
         self.get_widget('prompt_on_quit').set_active(value)
@@ -1241,7 +1261,7 @@ class PrefsDialog(SimpleGladeApp):
         self.set_cursor_blink_mode(value)
 
         value = self.settings.styleBackground.get_int('transparency')
-        self.get_widget('background_transparency').set_value(value)
+        self.get_widget('background_transparency').set_value(MAX_TRANSPARENCY - value)
 
         value = self.settings.general.get_int('window-valignment')
         self.get_widget('top_align').set_active(value)
