@@ -96,7 +96,6 @@ class GuakeTerminal(Vte.Terminal):
         self.configure_terminal()
         self.add_matches()
         self.connect('button-press-event', self.button_press)
-        self.connect('button-press-event', self.button_press)
         self.connect('child-exited', self.on_child_exited)
         self.matched_value = ''
         self.font_scale_index = 0
@@ -158,7 +157,10 @@ class GuakeTerminal(Vte.Terminal):
             self.set_allow_hyperlink(True)
 
         if (Vte.MAJOR_VERSION, Vte.MINOR_VERSION) >= (0, 56):
-            self.set_bold_is_bright(self.guake.settings.styleFont.get_boolean('bold-is-bright'))
+            try:
+                self.set_bold_is_bright(self.guake.settings.styleFont.get_boolean('bold-is-bright'))
+            except:  # pylint: disable=bare-except
+                log.error("set_bold_is_bright not supported by your version of VTE")
 
         # TODO PORT is this still the case with the newer vte version?
         # -- Ubuntu has a patch to libvte which disables mouse scrolling in apps
